@@ -327,16 +327,21 @@ bool LoadThemes()
     DIR             *dir;
     struct dirent   *dirEnt;
     Lum::Base::Path path;
+    Lum::Base::Path appPath;
+    Lum::Base::Path locPath;
 
-    path.SetNativeDir(Lum::Base::StringToWString(APP_DATADIR));
-    path.AppendDir(L"themes");
-    dir=opendir(Lum::Base::WStringToString(path.GetPath()).c_str());
+    appPath.SetNativeDir(Lum::Base::StringToWString(APP_DATADIR));
+    appPath.AppendDir(L"themes");
+    path=appPath;
+
+    dir=opendir(Lum::Base::WStringToString(appPath.GetPath()).c_str());
     if (dir==NULL) {
-      path.SetNativeDir(L"themes");
+      locPath.SetNativeDir(L"themes");
+      path=locPath;
 
-      dir=opendir(Lum::Base::WStringToString(path.GetPath()).c_str());
+      dir=opendir(Lum::Base::WStringToString(locPath.GetPath()).c_str());
       if (dir==NULL) {
-        std::cerr << "Cannot open theme directory as directory 'themes' or '" << Lum::Base::WStringToString(path.GetPath()) << "'" << std::endl;
+        std::cerr << "Cannot open theme directory as directory '" << Lum::Base::WStringToString(appPath.GetPath()) << "' or '" << Lum::Base::WStringToString(locPath.GetPath()) << "'" << std::endl;
         return false;
       }
     }
