@@ -538,10 +538,12 @@ public:
 
   Lum::Object* GetContent()
   {
-    Lum::Label       *label;
-    Lum::Panel       *panel,*hPanel,*vPanel;
-    Lum::Slider      *slider;
-    Lum::TextValue   *textValue;
+    Lum::Label        *label;
+    Lum::Panel        *panel,*hPanel,*vPanel;
+    Lum::Slider       *slider;
+    Lum::TextValue    *textValue;
+    /*Lum::Def::Boolean oneButtonModeDef(Lum::Def::Desc(L"One button mode"),
+                                       oneButtonMode);*/
 
     panel=Lum::HPanel::Create(true,false);
 
@@ -566,6 +568,11 @@ public:
 
     label->AddLabel(L"One button mode:",Lum::Boolean::Create(oneButtonMode));
 
+
+/*
+    label->AddLabel(L"One button mode:",
+                    Lum::OS::display->GetBehaviour()->GetBooleanControl(oneButtonModeDef));*/
+
     hPanel=Lum::HPanel::Create(true,false);
 
     textValue=new Lum::TextValue();
